/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.core;

import org.apache.log4j.Logger;

/**
 * Conversions to ISO 8601 format times.
 */
public class TimeInterval 
{
    private static final Logger m_log = Logger.getLogger(TimeInterval.class.getName());

    // Time interval received by constructor HH:MM:WW format.  e.g. "01:02:33"
    private String m_timeInterval;

    /**
     * Constructor
     *
     * @param timeInterval interval as a string HH:MM:SS
     */
    public TimeInterval(String timeInterval) 
    {
        m_timeInterval = timeInterval;
    }

    /**
     * Obtain ISO 8601 format time interval from elapsed time in seconds.
     *
     * @return ISO 8601 format time interval string
     */
    public String getIso8601() 
    {
        String[] fields = m_timeInterval.split(":");
        String returnValue = new String();

        // Process seconds
        if ((fields.length >= 3) && !fields[2].equals("00")) {
            if (fields[2].charAt(0) == '0') {
                fields[2] = fields[2].substring(1, 2);
            }

            returnValue = fields[2] + "S";
        }

        // Process minutes
        if ((fields.length >= 2) && !fields[1].equals("00")) {
            if (fields[1].charAt(0) == '0') {
                fields[1] = fields[1].substring(1, 2);
            }

            returnValue = fields[1] + "M" + returnValue;
        }

        // Process hours
        if ((fields.length >= 1) && !fields[0].equals("00")) {
            if (fields[0].charAt(0) == '0') {
                fields[0] = fields[0].substring(1, 2);
            }

            returnValue = fields[0] + "H" + returnValue;
        }

        if (returnValue.equals("")) {
            returnValue = "0S";
        }

        return "P" + returnValue;
    }

    /**
     * Return the time interval in seconds.
     *
     * @return number of seconds.
     */
    public String getSeconds() 
    {
        String[] fields = m_timeInterval.split(":");
        int seconds = 0;

        try {
            // Process seconds
            if (fields.length >= 3) {
                seconds = seconds + Integer.valueOf(fields[2]).intValue();
            }

            // Process minutes
            if (fields.length >= 2) {
                seconds = seconds +
                    (60 * Integer.valueOf(fields[1]).intValue());
            }

            // Process hours
            if (fields.length >= 1) {
                seconds = seconds +
                    (3600 * Integer.valueOf(fields[0]).intValue());
            }
        } catch (NumberFormatException e) {
            Log.warn(m_log,
                m_timeInterval + " is not a valid time interval", e);
        }

        return String.valueOf(seconds);
    }
}
