/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.core;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.TimeZone;

/**
 * Contains the current time, formatted into UTC. The date/time can
 * be refreshed using the updateDateTime() method.
 */
public class UTCTime {
    
    /**
     * Used to format the current date into yyyy-MM-DD (in UTC).
     */
    private SimpleDateFormat m_dateFormatter;
    
    /**
     * Used to format time into HH:mm:ss (in UTC).
     */
    private SimpleDateFormat m_timeFormatter;

    /**
     * The current date.
     */
    private String m_date;
    
    /**
     * The current time.
     */
    private String m_time;
    
    public UTCTime() {
        m_dateFormatter = new SimpleDateFormat("yyyy-MM-dd");
        m_dateFormatter.setTimeZone(TimeZone.getTimeZone("UTC"));
        m_timeFormatter = new SimpleDateFormat("HH:mm:ss");
        m_timeFormatter.setTimeZone(TimeZone.getTimeZone("UTC"));
        updateDateTime();
    }
    
    /**
     * Refreshes the current date/time.
     */
    public void updateDateTime() {
        Date currentTime = Calendar.getInstance().getTime();
        m_date = m_dateFormatter.format(currentTime);
        m_time = m_timeFormatter.format(currentTime);
    }
    
	/**
	 * Returns the current date.
	 */
	public String getDate() {
		return m_date;
	}
    
	/**
	 * Returns the current time.
	 */
	public String getTime() {
		return m_time;
	}
    
	/**
	 * Sets the current date.
	 */
	public void setDate(String date) {
		m_date = date;
	}
    
	/**
	 * Sets the current time.
	 */
	public void setTime(String time) {
		m_time = time;
	}
}
