/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.config.map;

import org.glite.apel.core.config.parser.ConfigMap;

/**
 * Maps a list of valid tokens that are interpreted on the command line
 * to internal ids (which can be manipulated by the application).
 * 
 * A map is fed into the CLParser and is used to validate the
 * users input on the command line. This simple map allows the user to
 * ask help, the version of the app and also to define a config file
 * using gnu-like notation (ie --help or -h etc).
 */
public class CLMap extends ConfigMap {
	
    /** 
     * User command line option to define a config file. 
     */
    private static final String CONFIG_FILE_TOK = "file";
    
    /** 
     * User command line option to define a config file. 
     */
    private static final String CONFIG_F_TOK = "f";
    
    /** 
     * User command line option to display help. 
     */
    private static final String HELP_TOK = "help";

    /** 
     * User command line option to display help. 
     */
    private static final String H_TOK = "h";
    
    /** 
     * User command line option to display the version. 
     */
    private static final String VERSION_TOK = "version";

    /** 
     * User command line option to display the version. 
     */
    private static final String V_TOK = "v";
    
    /** 
     * Location of the configuratoin file. 
     */
    public static final String PROP_CONFIG_FILE = "file";

    /** 
     * Help option. 
     */
    public static final String OPT_HELP = "help";

    /** 
     * Version option. 
     */
    public static final String OPT_VERSION = "version";    
    
	public CLMap() {
		setupOptions();
		setupParameters();
	}
	
	/**
	 * Adds all the user options to internal id mappings.
	 */
	private void setupOptions() {
		addOpt(HELP_TOK, OPT_HELP);
		addOpt(H_TOK, OPT_HELP);
		addOpt(VERSION_TOK, OPT_VERSION);
		addOpt(V_TOK, OPT_VERSION);
	}
	
	/**
	 * Adds all the user parameters to internal id mappings.
	 */
	private void setupParameters() {
		addParam(CONFIG_FILE_TOK, PROP_CONFIG_FILE);
		addParam(CONFIG_F_TOK, PROP_CONFIG_FILE);
	}
    
}
