/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.core.log.type;

/**
 * Represents an accounting record.
 */
public class AccountRecord {
    /**
     * The accounting record id.
     */
    private String m_recordId;
    /**
     * Site name where the accounting record was generated.
     */
    private String m_executingSite;
    /**
     * Name of job.
     */
    private String m_localJobId;
    /**
     * Locally generated user id.
     */
    private String m_localUserId;
    /**
     * Global user id of the job submitter.
     */
    private String m_lcgUserId;
    /**
     * Global job id of the job.
     */
    private String m_lcgJobId;
    /**
     * Local user group for associated user (ie VO group).
     */
    private String m_localUserVO;
    /**
     * Time elapsed while executing job.
     */
    private String m_elapsedTime;
    /**
     * Cpu duration period.
     */
    private String m_baseCPUTime;
    /**
     * Time elapsed while executing job (in seconds).
     */
    private String m_elapsedTimeSeconds;
    /**
     * Cpu duration period (in seconds).
     */
    private String m_baseCPUTimeSeconds;
    /**
     * Starting time of job.
     */
    private String m_startTime;
    /**
     * Time when job was stopped.
     */
    private String m_stopTime;
    /**
     * Starting time of job in UTC.
     */
    private String m_startTimeUtc;
    /**
     * Time when job was stopped in UTC.
     */
    private String m_stopTimeUtc;
    /**
     * Starting epoch for job.
     */
    private String m_startTimeEpoch;
    /**
     * Epoch when job was stopped.
     */
    private String m_stopTimeEpoch;
    private String executingCE;
    /**
     * Real memory used by the job.
     */
    private String m_memoryReal;
    /**
     * Virtual memory used by the job.
     */
    private String m_memoryVirtual;
    /**
     * The spec int value.
     */
    private String m_specInt2000;
    /**
     * The spec float value.
     */
    private String m_specFloat2000;
    /**
     * Date time stamp when job was created.
     */
    private String m_eventDate;
    /**
     * Date when record was created.
     */
    private String m_eventTime;
    public AccountRecord() {}
    /**
     * Gets the accounting record id.
     */
    public String getRecordId() {
        return m_recordId;
    }
    /**
     * Gets the site name where the accounting record was generated.
     */
    public String getExecutingSite() {
        return m_executingSite;
    }
    /**
     * Gets the job name.
     */
    public String getLocalJobId() {
        return m_localJobId;
    }
    /**
     * Gets the local user ID of the user running the job.
     */
    public String getLocalUserId() {
        return m_localUserId;
    }
    /**
     * Gets the lcg user id.
     */
    public String getLcgUserId() {
        return m_lcgUserId;
    }
    /**
     * Gets the lcg job id.
     */
    public String getLcgJobId() {
        return m_lcgJobId;
    }
    /**
     * Gets the local user group of the job.
     */
    public String getLocalUserVO() {
        return m_localUserVO;
    }
    /**
     * Gets the time duration of the job.
     */
    public String getElapsedTime() {
    	return m_elapsedTime;
    }
    /**
     * Gets the CPU time used by the job.
     */
    public String getBaseCPUTime() {
    	return m_baseCPUTime;
    }
    /**
     * Gets the CPU duration in seconds.
     */
    public String getElapsedTimeSeconds() {
        return m_elapsedTimeSeconds;
    }
    /**
     * Gets the CPU duration in seconds.
     */
    public String getBaseCPUTimeSeconds() {
        return m_baseCPUTimeSeconds;
    }
    /**
     * Gets the start time.
     */
    public String getStartTime() {
        return m_startTime;
    }
    /**
     * Gets the stop time.
     */
    public String getStopTime() {
        return m_stopTime;
    }
    /**
     * Gets the start time in utc.
     */
    public String getStartTimeUtc() {
        return m_startTimeUtc;
    }
    /**
     * Gets the stop time epoch.
     */
    public String getStopTimeEpoch() {
        return m_stopTimeEpoch;
    }
    /**
     * Gets the start time epoch value.
     */
    public String getStartTimeEpoch() {
        return m_startTimeEpoch;
    }
    /**
     * Gets the stop time in utc.
     */
    public String getStopTimeUtc() {
        return m_stopTimeUtc;
    }
    /**
     * Returns the CE where the job was executed.
     */
    public String getExecutingCE() {
        return executingCE;
    }
    /**
     * Gets the real memory attribute.
     */
    public String getMemoryReal() {
        return m_memoryReal;
    }
    /**
     * Gets the virtual memory attribute.
     */
    public String getMemoryVirtual() {
        return m_memoryVirtual;
    }
    /**
     * Gets the spec int 2000 value.
     */
    public String getSpecInt2000() {
        return m_specInt2000;
    }
    /**
     * Gets the spec float 2000 value.
     */
    public String getSpecFloat2000() {
        return m_specFloat2000;
    }
    /**
     * Gets the event date.
     */
    public String getEventDate() {
        return m_eventDate;
    }
    /**
     * Gets the event time.
     */
    public String getEventTime() {
        return m_eventTime;
    }
    /**
     * Sets the record id.
     */
    public void setRecordId(String recordId) {
        m_recordId = recordId;
    }
    /**
     * Sets the site name.
     */
    public void setExecutingSite(String executingSite) {
        m_executingSite = executingSite;
    }
    /**
     * Sets the local job id.
     */
    public void setLocalJobId(String name) {
        m_localJobId = name;
    }
    /**
     * Sets the local user id.
     */
    public void setLocalUserId(String userId) {
        m_localUserId = userId;
    }
    /**
     * Sets the lcg user id.
     */
    public void setLcgUserId(String lcgUserId) {
        m_lcgUserId = lcgUserId;
    }
    /**
     * Sets the lcg job id.
     */
    public void setLcgJobId(String lcgJobId) {
        m_lcgJobId = lcgJobId;
    }
    /**
     * Sets the VO the job submitter belongs to.
     */
    public void setLocalUserVO(String userVO) {
        m_localUserVO = userVO;
    }
    /**
     * Sets the elapsed time.
     */
    public void setElapsedTime(String elapsedTime) {
    	m_elapsedTime = elapsedTime;
    }
    /**
     * Sets the base cpu time.
     */
    public void setBaseCPUTime(String cpuTime) {
    	m_baseCPUTime = cpuTime;
    }
    /**
     * Sets the elapsed time (in seconds).
     */
    public void setElapsedTimeSeconds(String elapsedTime) {
        m_elapsedTimeSeconds = elapsedTime;
    }
    /**
     * Sets the base cpu time (in seconds).
     */
    public void setBaseCPUTimeSeconds(String cpuTime) {
        m_baseCPUTimeSeconds = cpuTime;
    }
    /**
     * Sets the start time.
     */
    public void setStartTime(String time) {
        m_startTime = time;
    }
    /**
     * Sets the stop time.
     */
    public void setStopTime(String time) {
        m_stopTime = time;
    }
    /**
     * Sets the start time in utc.
     */
    public void setStartTimeUtc(String timeUtc) {
        m_startTimeUtc = timeUtc;
    }
    /**
     * Sets the stop time in utc.
     */
    public void setStopTimeUtc(String timeUtc) {
        m_stopTimeUtc = timeUtc;
    }
    /**
     * Sets the start time epoch.
     */
    public void setStartTimeEpoch(String timeEpoch) {
        m_startTimeEpoch = timeEpoch;
    }
    /**
     * Sets the stop time epoch.
     */
    public void setStopTimeEpoch(String timeEpoch) {
        m_stopTimeEpoch = timeEpoch;
    }
    /**
     * Sets the executing CE.
     */
     public void setExecutingCE(String executingCE) {
        this.executingCE = executingCE;
     }
    /**
     * Sets the real memory used by the job.
     */
    public void setMemoryReal(String real) {
        m_memoryReal = real;
    }
    /**
     * Sets the virtual memory used by the job.
     */
    public void setMemoryVirtual(String virtual) {
        m_memoryVirtual = virtual;
    }
    /**
     * Sets the spec int 2000 value.
     */
    public void setSpecInt2000(String specInt2000) {
        m_specInt2000 = specInt2000;
    }
   /**
    * Sets the spec float 2000 value.
    */
    public void setSpecFloat2000(String specFloat2000) {
        m_specFloat2000 = specFloat2000;
    }
    /**
     * Sets the event date.
     */
    public void setEventDate(String date) {
        m_eventDate = date;
    }
    /**
     * Sets the event time.
     */
    public void setEventTime(String time) {
        m_eventTime = time;
    }
}
