/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.type;

import java.util.Iterator;
import java.util.ArrayList;

/**
 * Convenience class that provides a wrapper around a list of
 * AccountRecords (this provides stronger static type checking).
 */
public class AccountRecordIterator {

    /**
     * The iterator used when travesing the list of event records.
     */
    private Iterator m_iterator;
    
    /**
     * Number of elements contained in the list.
     */
    private int m_count;
    
    public AccountRecordIterator(ArrayList accountRecords) {
        m_iterator = accountRecords.iterator();
        m_count = accountRecords.size();
    }
    
    /**
     * Returns true if there are more elements to iterate.
     */
    public boolean hasNext() {
        return m_iterator.hasNext();
    }
    
    /**
     * Gets the next AccountRecord if one exists.
     */
    public AccountRecord next() {
        return (AccountRecord) m_iterator.next();
    }
    
    /**
     * Returns the number of elements stored in the list.
     */
    public int count() {
    	return m_count;
    }
 
    public void close() {
	m_iterator = null;
    }   
}
