/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.type;

/**
 * Represents an accounting summary record
 */
public class AccountSummary {
    /**
     * The accounting record id.
     */
    private String m_recordId;
    /**
     * Site name where the accounting record was generated.
     */
    private String m_executingSite;
    /**
     * Total Time elapsed while executing job (in seconds).
     */
    private String m_elapsedTimeSeconds;
    /**
     * Total Cpu duration period (in seconds).
     */
    private String m_baseCpuTimeSeconds;
    /**
     * Date time stamp when job was created.
     */
    private String m_recordStart;
    /**
     * Date time stamp when job was created.
     */
    private String m_recordEnd;

    /**
     * Number of Jobs in summary.
     */
    private String m_Njobs;

    /**
     * Number of Days in summary.
     */
    private String m_Ndays;


    public AccountSummary() {}

    /**
     * Gets the accounting record id.
     */
    public String getRecordId() {
        return m_recordId;
    }
    /**
     * Gets the site name where the accounting record was generated.
     */
    public String getExecutingSite() {
        return m_executingSite;
    }
    /**
     * Gets the CPU duration in seconds.
     */
    public String getElapsedTimeSeconds() {
        return m_elapsedTimeSeconds;
    }
    /**
     * Gets the CPU duration in seconds.
     */
    public String getBaseCpuTimeSeconds() {
        return m_baseCpuTimeSeconds;
    }
    /**
     * Gets the event date.
     */
    public String getRecordStart() {
        return m_recordStart;
    }
    /**
     * Gets the event date.
     */
    public String getRecordEnd() {
        return m_recordEnd;
    }
    /**
     * Gets the Number of Jobs.
     */
    public String getNjobs() {
        return m_Njobs;
    }
    /**
     * Gets the Number of Days.
     */
    public String getNdays() {
        return m_Ndays;
    }


    /**
     * Sets the record id.
     */
    public void setRecordId(String recordId) {
        m_recordId = recordId;
    }
    /**
     * Sets the site name.
     */
    public void setExecutingSite(String executingSite) {
        m_executingSite = executingSite;
    }
    /**
     * Sets the elapsed time (in seconds).
     */
    public void setElapsedTimeSeconds(String elapsedTime) {
        m_elapsedTimeSeconds = elapsedTime;
    }
    /**
     * Sets the base cpu time (in seconds).
     */
    public void setBaseCpuTimeSeconds(String cpuTime) {
        m_baseCpuTimeSeconds = cpuTime;
    }
    /**
     * Sets the event date.
     */
    public void setRecordStart(String date) {
        m_recordStart = date;
    }
    /**
     * Sets the event date.
     */
    public void setRecordEnd(String date) {
        m_recordEnd = date;
    }
    /**
     * Sets the Number of Jobs.
     */
    public void setNjobs(String njobs) {
        m_Njobs = njobs;
    }
    /**
     * Sets the Number of Jobs.
     */
    public void setNdays(String ndays) {
        m_Ndays = ndays;
    }


}
