/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.type;

/**
 * A job record parsed from a BLAHD log file.
 */
public class BlahdRecord {

    /**
     * LRMS Submission Time
     */
    private String m_timeStamp, m_date, m_time;
    
    /**
     * userDN
     */
    private String m_userDN;
    
    /**
     * userFQAN
     */
    private String m_userFQAN;
    
    /**
     * ceID
     */
    private String m_ceId;
    
    /**
     * LRMS ID
     */
    private String m_LrmsId;
    
    /**
     * Global Job Identier
     */
    private String m_jobId;
    
    /**
     * Start time that Balhd record is Valid
     */
    private String m_validFrom;

    /**
     * End time that Blahd record is Valid
     */
    private String m_validUntil;

    /**
     * The LRMS submit Host
     */
     private String m_submitHost;

    /**
     * The JobName = lrmsID.LRMS_server_host_name
     */
     private String m_jobName;

    /**
     * Gets the LRMS Submission timeStamp
     */
    public String getTimeStamp() {
        return m_timeStamp;
    }
    public String getTime() {
        return m_time;
    }
    public String getDate() {
        return m_date;
    }
    /**
     * Gets the userDN
     */
    public String getUserDN() {
        return m_userDN;
    }

    /**
     * Gets the job name.
     */
    public String getUserFQAN() {
        return m_userFQAN;
    }

    /**
     * Gets the local user group of the job.
     */
    public String getCeId() {
        return m_ceId;
    }

    /**
     * Gets the local user ID of the user running the job.
     */
    public String getLrmsId() {
        return m_LrmsId;
    }

    /**
     * Gets the Global Job ID of the user running the job.
     */
    public String getJobId() {
        return m_jobId;
    }

    /**
     * Gets the submit host.
     */
    public String getSubmitHost() {
        return m_submitHost;
    }

    /**
     * Gets the jobName.
     */
    public String getJobName() {
        return m_jobName;
    }

   /**
     * Sets the valid from attribute.
     */
    public String getValidFrom() {
        return m_validFrom;
    }

    /**
     * Sets the valid until attribute.
     */
    public String getValidUntil() {
        return m_validUntil;
    }

    /**
     * Sets the timeStamp
     */
    public void setTimeStamp(String timeStamp) {
        m_timeStamp = timeStamp;
    }
    public void setTime(String time) {
        m_time = time;
    }
    public void setDate(String date) {
        m_date = date;
    }
    
    /**
     * Sets the UserDN
     */
     public void setUserDN(String userDN) {
        m_userDN = userDN;
     }

    /**
     * Sets the UserFQAN
     */
     public void setUserFQAN(String userFQAN) {
        m_userFQAN = userFQAN;
     }

    /**
     * Sets the ceId
     */
     public void setCeId(String ceId) {
        m_ceId = ceId;
     }

    /**
     * Sets the localJobId
     */
     public void setLrmsId(String lrmsId) {
        m_LrmsId = lrmsId;
     }

    /**
     * Sets the Global Job Id
     */
     public void setJobId(String jobId) {
        m_jobId = jobId;
     }

   /**
     * Sets the valid from attribute.
     */
    public void setValidFrom(String from) {
        m_validFrom = from;
    }

    /**
     * Sets the valid until attribute.
     */
    public void setValidUntil(String until) {
        m_validUntil = until;
    }
    
    /**
     * Sets the submit host.
     */
    public void setSubmitHost(String host) {
        m_submitHost = host;
    }

    /**
     * Sets the jobName.
     */
    public void setJobName(String jobName) {
        m_jobName = jobName;
    }
}
