/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.type;

/**
 * A job record parsed from a PBS log file.
 */
public class EventRecord {

    /**
     * Cpu duration period.
     */
    private String m_cpuDuration;
    
    /**
     * Cpu duration defined in seconds.
     */
    private String m_cpuDurationSeconds;
    
    /**
     * Name of job.
     */
    private String m_jobName;
    
    /**
     * Local user group for associated user (ie VO group).
     */
    private String m_localUserGroup;
    
    /**
     * Locally generated user id.
     */
    private String m_localUserID;
    
    /**
     * Date time stamp when job was created.
     */
    private String m_eventDate;
    
    /**
     * Date when record was created.
     */
    private String m_eventTime;
    
    /**
     * Time when record was created.
     */
    private String m_memoryReal;
    
    /**
     * Virtual memory used by job.
     */
    private String m_memoryVirtual;
    
    /**
     * Starting time of job.
     */
    private String m_startTime;
    
    /**
     * Starting epoch for job.
     */
    private String m_startTimeEpoch;
    
    /**
     * Starting time of job in UTC.
     */
    private String m_startTimeUtc;
    
    /**
     * Time when job was stopped.
     */
    private String m_stopTime;
    
    /**
     * Epoch when job was stopped.
     */
    private String m_stopTimeEpoch;
    
    /**
     * Time when job was stopped in UTC.
     */
    private String m_stopTimeUtc;
    
    /**
     * Hostname that submitted the job.
     */
    private String m_submitHost;
    
    /**
     * Wall clock time elapsed while job was running.
     */
    private String m_wallDuration;
    
    /**
     * As above (in seconds).
     */
    private String m_wallDurationSeconds;

    /**
     * Gets the CPU duration of the job as a time string.
     */
    public String getCpuDuration() {
        return m_cpuDuration;
    }

    /**
     * Gets the CPU duration in seconds.
     */
    public String getCpuDurationSeconds() {
        return m_cpuDurationSeconds;
    }

    /**
     * Gets the job name.
     */
    public String getJobName() {
        return m_jobName;
    }

    /**
     * Gets the local user group of the job.
     */
    public String getLocalUserGroup() {
        return m_localUserGroup;
    }

    /**
     * Gets the local user ID of the user running the job.
     */
    public String getLocalUserID() {
        return m_localUserID;
    }

    /**
     * Gets the measurement date attribute.
     */
    public String getEventDate() {
        return m_eventDate;
    }

    /**
     * Gets the measurement time attribute.
     */
    public String getEventTime() {
        return m_eventTime;
    }

    /**
     * Gets the real memory attribute.
     */
    public String getMemoryReal() {
        return m_memoryReal;
    }

    /**
     * Gets the virtual memory attribute.
     */
    public String getMemoryVirtual() {
        return m_memoryVirtual;
    }

    /**
     * Gets the start time.
     */
    public String getStartTime() {
        return m_startTime;
    }

    /**
     * Gets the start time epoch value.
     */
    public String getStartTimeEpoch() {
        return m_startTimeEpoch;
    }

    /**
     * Gets the start time in utc.
     */
    public String getStartTimeUtc() {
        return m_startTimeUtc;
    }

    /**
     * Gets the stop time.
     */
    public String getStopTime() {
        return m_stopTime;
    }

    /**
     * Gets the stop time epoch.
     */
    public String getStopTimeEpoch() {
        return m_stopTimeEpoch;
    }

    /**
     * Gets the stop time in utc.
     */
    public String getStopTimeUtc() {
        return m_stopTimeUtc;
    }

    /**
     * Gets the submit host.
     */
    public String getSubmitHost() {
        return m_submitHost;
    }

    /**
     * Gets the wall duraction.
     */
    public String getWallDuration() {
        return m_wallDuration;
    }

    /**
     * Gets the wall duration in seconds.
     */
    public String getWallDurationSeconds() {
        return m_wallDurationSeconds;
    }
    
    /**
     * Sets the cpuDuration.
     */
    public void setCpuDuration(String duration) {
         m_cpuDuration = duration;
    }
    
   /**
    *	 
    */
    public void setCpuDurationSeconds(String durationSeconds) {
         m_cpuDurationSeconds = durationSeconds;
    }
    
   /**
    *	 
    */
    public void setJobName(String name) {
         m_jobName = name;
    }
    
   /**
    *	 
    */
    public void setLocalUserGroup(String userGroup) {
         m_localUserGroup = userGroup;
    }
    
   /**
    *
    */
    public void setLocalUserID(String userID) {
         m_localUserID = userID;
    }
    
   /**
    *
    */
    public void setEventDate(String date) {
         m_eventDate = date;
    }
    
   /**
    *	 
    */
    public void setEventTime(String time) {
         m_eventTime = time;
    }

   /**
    *
    */
    public void setMemoryReal(String real) {
         m_memoryReal = real;
    }
    
   /**
    *
    */
    public void setMemoryVirtual(String virtual) {
         m_memoryVirtual = virtual;
    }
    
   /**
    *
    */
    public void setStartTime(String time) {
         m_startTime = time;
    }
    
   /**
    *	 
    */
    public void setStartTimeEpoch(String timeEpoch) {
         m_startTimeEpoch = timeEpoch;
    }
    
   /**
    *
    */
    public void setStartTimeUtc(String timeUtc) {
         m_startTimeUtc = timeUtc;
    }
    
   /**
    *
    */
    public void setStopTime(String time) {
         m_stopTime = time;
    }
    
   /**
    *
    */
    public void setStopTimeEpoch(String timeEpoch) {
         m_stopTimeEpoch = timeEpoch;
    }
    
   /**
    * 
    */
    public void setStopTimeUtc(String timeUtc) {
         m_stopTimeUtc = timeUtc;
    }
    
   /**
    *
    */
    public void setSubmitHost(String host) {
         m_submitHost = host;
    }
    
   /**
    *
    */
    public void setWallDuration(String duration) {
         m_wallDuration = duration;
    }
    
   /**
    *
    */
    public void setWallDurationSeconds(String durationSeconds) {
         m_wallDurationSeconds = durationSeconds;
    }

}
