/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.type;

/**
 * A job record derived from a Globus Gatekeeper log file.
 */
public class GkRecord {
    
    /**
     * The DN of the user.
     */
    private String m_globalUserName;
    
    /**
     * The gram id of the user.
     */
    private String m_gramScriptJobID;
    
    /**
     * The local job id.
     */
    private String m_localJobID;
    
    /**
     * Date when record was generated.
     */
    private String m_measurementDate;
    
    /**
     * Time when record was generated.
     */
    private String m_measurementTime;
    
    /**
     * Starting time when gk record is valid.
     */
    private String m_validFrom;
    
    /**
     * End time when gk record is valid.
     */
    private String m_validUntil;
    
    /**
     * Flag indicates if the gk record is using an lcg pbs logging
     * format.  
     */
    private boolean m_lcgPbs;
    
    /**
     * Creates a new GkRecord.
     */
    public GkRecord() {}

    /**
     * Gets the global user name of the record.
     */
    public String getGlobalUserName() {
        return m_globalUserName;
    }

    /**
     * Gets the Gram job ID of the record.
     */
    public String getGramScriptJobID() {
        return m_gramScriptJobID;
    }

    /**
     * Gets the local job ID of the record.
     */
    public String getLocalJobID() {
        return m_localJobID;
    }

    /**
     * Gets the measurement date of the record.
     */
    public String getMeasurementDate() {
        return m_measurementDate;
    }

    /**
     * Gets the measurement time of the record.
     */
    public String getMeasurementTime() {
        return m_measurementTime;
    }

    /**
     * Gets valid from attribute.
     */
    public String getValidFrom() {
        return m_validFrom;
    }

    /**
     * Gets valid until attribute.
     */
    public String getValidUntil() {
        return m_validUntil;
    }

    /**
     * Returns true only if the job name is an internal id (i.e will the 
     * job name match the job name used in the Pbs event logs).
     */
    public boolean isLcgPbs() {
        return m_lcgPbs;
    }
    
    /**
     * Sets the global user name.
     */
    public void setGlobalUserName(String userName) {
        m_globalUserName = userName;
    }
    
    /**
     * Sets the gram script id.
     */
    public void setGramScriptJobID(String scriptJobID) {
        m_gramScriptJobID = scriptJobID;
    }
    
    /**
     * Sets the local job id.
     */
    public void setLocalJobID(String jobID) {
        m_localJobID = jobID;
    }
    
    /**
     * Sets the measurement date.
     */
    public void setMeasurementDate(String date) {
        m_measurementDate = date;
    }
    
    /**
     * Sets the measurement time.
     */
    public void setMeasurementTime(String time) {
        m_measurementTime = time;
    }
    
    /**
     * Sets the valid from attribute.
     */
    public void setValidFrom(String from) {
        m_validFrom = from;
    }
    
    /**
     * Sets the valid until attribute.
     */
    public void setValidUntil(String until) {
        m_validUntil = until;
    }
    
    /**
     * Sets the lcg pbs flag (to indicate the gk record was logged
     * using a pbs batch system).
     */
    public void setLcgPbs(boolean isLcgPbs) {
    	m_lcgPbs = isLcgPbs;
    }
    
}
