/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.core.log.type;

/**
 * A job record parsed from the system message log.
 */
public class MsgRecord {
    
    /**
     * The gram script job id of the record.
     */
    private String m_gramId;
    
    /**
     * The job name derived from the current record.
     */
    private String m_jobName;
    
    /**
     * Current measurement date when record was read-in.
     */
    private String m_measurementDate;
    
    /**
     * Current measurement time when record was read-in.
     */
    private String m_measurementTime;
    
    /**
     * Valid from timestamp.
     */
    private String m_validFrom;
    
    /**
     * Valid until timestamp.
     */
    private String m_validUntil;
    
    public MsgRecord() {}

    /**
     * Returns the gram script job id.
     */
    public String getGramScriptJobID() {
        return m_gramId;
    }

    /**
     * Returns the job name.
     */
    public String getJobName() {
        return m_jobName;
    }

    /**
     * Returns the measurement date.
     */
    public String getMeasurementDate() {
        return m_measurementDate;
    }

    /**
     * Returns the measurement time.
     */
    public String getMeasurementTime() {
        return m_measurementTime;
    }

    /**
     * Returns the valid from attribute.
     */
    public String getValidFrom() {
        return m_validFrom;
    }

    /**
     * Returns the valid until attribute.
     */
    public String getValidUntil() {
        return m_validUntil;
    }
    
    /**
     * Sets the gram script id.
     */
    public void setGramId(String id) {
      m_gramId = id;
    }
    
    /**
     * Sets the job name attribute.
     */
    public void setJobName(String name) {
      m_jobName = name;
    }
    
    /**
     * Sets the measurement date.
     */
    public void setMeasurementDate(String date) {
      m_measurementDate = date;
    }
    
    /**
     * Sets the measurement time.
     */
    public void setMeasurementTime(String time) {
      m_measurementTime = time;
    }
    
    /**
     * Sets the valid from property.
     */
    public void setValidFrom(String from) {
      m_validFrom = from;
    }
    
    /**
     * Sets the valid until property.
     */
    public void setValidUntil(String until) {
      m_validUntil = until;
    }
    
}
