/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.processor;

import org.apache.log4j.Logger;
import org.glite.apel.core.ApelException;
import org.glite.apel.core.Log;
import org.glite.apel.core.db.ApelDB;
import org.glite.apel.core.db.MySQLImpl;

/**
 * Processor is used to scrub all the data from the database tables.
 */
public class DeleteProcessor {
	
    /**
     * Reference to logging tool.
     */
    private static final Logger m_log = 
    	Logger.getLogger(DeleteProcessor.class.getName());

    /**
     * Mysql db interface.
     */
    private ApelDB m_db;
    
    public DeleteProcessor(String url, String username, String password, 
        String siteName) throws ApelException {
        m_db = new MySQLImpl(url, username, password, siteName);
    }
                 
    /**
     * Process the event log files which have not so far been processed.
     */
    public void run(boolean deleteAll) throws ApelException {
        Log.info(m_log, "**** Clearing database tables ****");
        if (deleteAll) {
            Log.info(m_log, "Removing all records");
            m_db.deleteAllRecords(ApelDB.GK_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.EVENT_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.MSG_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.LCG_RECORDS_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.SPEC_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.PROCESSED_FILES_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.REPUBLISH_TABLE_NAME);
            m_db.deleteAllRecords(ApelDB.BLAHD_TABLE_NAME);
        } else {
            Log.info(m_log, "Only removing processed log records");
            m_db.deleteProcessedEventRecords();
            m_db.deleteProcessedGkRecords();
            m_db.deleteProcessedMsgRecords();
            m_db.deleteProcessedBlahdRecords();
        }
    }
    
    /**
     * Tidies-up any loose resources.
     */
    public void close() {
        m_db.close();
    }
    
}
