/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
package org.glite.apel.core.log.parser;

import java.io.File;
import java.io.IOException;
import org.glite.apel.core.ApelException;
import org.glite.apel.core.log.parser.BlahdLogParser;
import org.glite.apel.core.log.type.BlahdRecord;
import junit.framework.TestCase;
import junit.framework.TestSuite;
/**
 * Test the BlahdLogParser class.
 */
public class BlahdLogParserTest extends TestCase {
    /**
     * timestamp.
     */
    private String m_timestamp = "2006-04-26 09:21:34";
    /**
     * date.
     */
    private String m_date      = "2006-04-26";
    /**
     * time.
     */
    private String m_time      = "09:21:34";
    /**
     * userDN.
     */
    private String m_userDN    = "/C=UK/O=eScience/OU=QueenMaryLondon/L=Physics/CN=dave kant";
    /**
     * primary userFQAN.
     */
    private String m_userFQAN_1 = "/dteam/Role=NULL/Capability=NULL";
    
    /**
     * secondary userFQAN.
     */
    private String m_userFQAN_2 = "/dteam/cern/Role=NULL/Capability=NULL";

    /**
     * Chained userFQAN.
     */
    private String m_chainFQAN = m_userFQAN_1 + ";" + m_userFQAN_2 + ";";

    /**
     * ceid.
     */
    private String m_ceId      = "lcgce02.gridpp.rl.ac.uk:2119/blah-pbs";
    /**
     * jobId.
     */
    private String m_jobId     = "https://lxb2016.cern.ch:9000/_nQd93Hk6-33qNk6kCO_eQ";
    /**
     * lrmsID.
     */
    private String m_lrmsId    = "14424.lcgce02.gridpp.rl.ac.uk";
    /**
     * LRMS Submit Host.
     */
    private String m_submitHost  = "lcgce02.gridpp.rl.ac.uk";
    /**
     * job record.
     */
    private String m_line = "\"timestamp=" + m_timestamp + "\" " +
             "\"userDN=" + m_userDN + "\" " + "\"userFQAN=" + m_userFQAN_1 + "\" " +
             "\"userFQAN=" + m_userFQAN_2 + "\" " +
             "\"ceID=" + m_ceId + "\" " + "\"jobID=" + m_jobId + "\" " + "\"lrmsID=" + m_lrmsId + "\"";
    /**
     * Junit suite() .
     */
    public static junit.framework.Test suite() {
        return new TestSuite(BlahdLogParserTest.class);
    }
   /**
    * Tests Blahd Accounting Log is correctly interpreted.
    */
    public void testParseBlahd() {
        String input = m_line;
        File tmp = null;
        try {
            tmp = File.createTempFile("unittest", "tmp");
            tmp.deleteOnExit();
        } catch (IOException ioe) {
            fail();
        }
        try {
            BlahdLogParser parser = new BlahdLogParser(tmp,m_submitHost);
             
            BlahdRecord record = parser.createBlahdRecord(input);
            assertEquals(record.getTimeStamp(), m_timestamp);
            assertEquals(record.getDate(), m_date);
            assertEquals(record.getTime(), m_time);
            assertEquals(record.getUserDN(), m_userDN);
            assertEquals(record.getUserFQAN(), m_chainFQAN);
            assertEquals(record.getCeId(), m_ceId);
            assertEquals(record.getLrmsId(), m_lrmsId);
            assertEquals(record.getJobId(), m_jobId);
            assertEquals(record.getSubmitHost(), m_submitHost);

        } catch (Exception e) {
            fail( e.toString() );
        }
    }
}
