/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.glite.apel.core.log.parser;

import java.io.File;
import java.io.IOException;

import org.glite.apel.core.ApelException;
import org.glite.apel.core.log.parser.MsgLogParser;
import org.glite.apel.core.log.type.MsgRecord;

import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Test the org.edg.info.apel.MessageLogRecord class
 */
public class MsgLogParserTest extends TestCase {
	
    private String time = "10:31:12";
    private String date = "Mar 11";
    private String ce = "hik-lcg-ce";
    private String prefixID = "[13028-13163]";
    private String jobNumber = "1078997435";
    private String prefix = date + " " + time + " " + ce + " gridinfo: " + prefixID + " Submitted job " + jobNumber;
    private String jobInternalID = "internal_656690420:13028.1078997433";
    private String middle = jobInternalID + " to batch system";
    private String jobName = "906721.pbs-server2";
    private String suffix = "with ID " + jobName;
    private String lcgpbsLine = prefix + ":lcgpbs:" + middle + " lcgpbs " + suffix;
    private String pbsproLine = prefix + ":pbspro:" + middle + " pbspro " + suffix;

    public static junit.framework.Test suite() {
        return new TestSuite(MsgLogParserTest.class);
    }

    /**
     * Tests system message logs of type 'lcgpbs' are interpreted.
     */
    public void testParseLcgpbs() {
        String input = lcgpbsLine;
        File tmp = null;
        try {
            tmp = File.createTempFile("unittest", "tmp");
            tmp.deleteOnExit();
        } catch (IOException ioe) {
            fail();
        }
        try {
            MsgLogParser parser = new MsgLogParser(tmp, MsgLogParser.PBS_FORMAT);
            MsgRecord record = parser.createMessageRecord(input);
            assertEquals(record.getJobName(), jobName);
            assertEquals(record.getGramScriptJobID(),jobNumber + ":lcgpbs:" + jobInternalID);
        } catch (ApelException e) {
            fail(e.toString());
        }
    }

    /**
     * Tests system message logs of type 'pbspro' are interpreted.
     */
    public void testParsePbspro() {
        String input = pbsproLine;
        File tmp = null;
        try {
            tmp = File.createTempFile("unittest", "tmp");
            tmp.deleteOnExit();
        } catch (IOException ioe) {
            fail();
        }
        try {
            MsgLogParser parser = new MsgLogParser(tmp, MsgLogParser.PBS_FORMAT);
            MsgRecord record = parser.createMessageRecord(input);
            assertEquals(record.getJobName(), jobName);
            assertEquals(record.getGramScriptJobID(),
                jobNumber + ":pbspro:" + jobInternalID);
        } catch (ApelException e) {
            fail(e.toString());
        }
    }
    
}
